@@ -1,12 +1,7 @@
 #!/usr/bin/perl -w
 
-$lines = "
-ValA = 7
-
-ValA : (default ValA defA)
-ValB : (default ValB defB)
-";
-@lines = split(/\n/,$lines);
+@lines = <DATA>;
+chomp(@lines);
 
 use List::Parseable;
 $lp     = new List::Parseable;
@@ -45,3 +40,9 @@ sub parse_value {
    set_value($var,$val);
 }
 
+__DATA__
+
+ValA = 7
+
+ValA : (default ValA defA)
+ValB : (default ValB defB)
